@@ -755,6 +755,34 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeTopicSubscribeGroup(self, request):
+        """查询订阅某主题消息分组信息
+
+        :param request: Request instance for DescribeTopicSubscribeGroup.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DescribeTopicSubscribeGroupRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DescribeTopicSubscribeGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeTopicSubscribeGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeTopicSubscribeGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeUser(self, request):
         """查询用户信息
 
@@ -783,6 +811,34 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def FetchMessageByOffset(self, request):
+        """根据指定offset位置的消息
+
+        :param request: Request instance for FetchMessageByOffset.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.FetchMessageByOffsetRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.FetchMessageByOffsetResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("FetchMessageByOffset", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.FetchMessageByOffsetResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyGroupOffsets(self, request):
         """设置Groups 消费分组offset
 
