@@ -229,3 +229,6 @@ RESOURCENOTFOUND_SHIPPERTASKNOTEXIST = 'ResourceNotFound.ShipperTaskNotExist'
 
 # 日志主题不存在。
 RESOURCENOTFOUND_TOPICNOTEXIST = 'ResourceNotFound.TopicNotExist'
+
+# 操作不支持。
+UNSUPPORTEDOPERATION = 'UnsupportedOperation'
